function fitinfo = MMAfterfit(tdata,ydata,param,fitinfo)
%   Called after fitting to plot data.
%
%   Input:  ydata = Progress curve data used for fitting.
%           tdata = Time datapoints used for fitting.
%           param = Parameters from the least-square estimator to be
%                   annotated.
%           fitinfo = Collection of all the fitting info of the
%                     corresponding Fit
%   Output: fitinfo = For possible future use.

% Choose annotation depending on the fittype
switch fitinfo.fittype
    case 'Analytic'
        % For analytic fit the parameters are: S0, KM, vM, dt, {kL/L}, RES
        figure(10)
        annotString={['[S0]  = ' sprintf('%3.3f',param(1))]...
              ['{K_M}  = ' sprintf('%3.3f',param(2))]...
              ['{V_M}  = ' sprintf('%3.3f',param(3))]...
              ['{t_{Off}}= ' sprintf('%3.3f',param(4))]...
              [' ']};
        if length(param)==5
          annotString=[annotString {['Res = ' sprintf('%3.3f',param(5))]}];
        elseif length(param) == 6
          annotString=[annotString {['kL/L = ' sprintf('%3.3f',param(5))]...
              ['Res = ' sprintf('%3.3f',param(6))]}];
        end

    case 'Numeric'
        % For numeric fit the parameters are: S0, KM, vM, dt, {kL/L}, RES
        figure(11)
        annotString={['[S0]  = ' sprintf('%3.3f',param(1))]...
              ['{K_M}  = ' sprintf('%3.3f',param(2))]...
              ['{V_M}  = ' sprintf('%3.3f',param(3))]...
              ['{t_{Off}}= ' sprintf('%3.3f',param(4))]};
          if length(param)==5
              annotString=[annotString {[' ']...
                  ['Res = ' sprintf('%3.3f',param(5))]}];
          elseif length(param) == 6
              annotString=[annotString {['kL/L = ' sprintf('%3.3f',param(5))]...
                  ['Res = ' sprintf('%3.3f',param(6))]}];
          end

    case 'Simulation'
        % For simulation fit the parameters are: E, S, kF, kR, kCat, dT
        figure(12)
        annotString={['[E] = ' sprintf('%3.3f',param(1))]...
              ['[S] = ' sprintf('%3.3f',param(2))]...
              ['kF  = ' sprintf('%3.3f',param(3))]...
              ['kR  = ' sprintf('%3.3f',param(4))]...
              ['kCat= ' sprintf('%3.3f',param(5))]...
              ['dT  = ' sprintf('%3.3f',param(6))]};
          if length(param)==7
              annotString=[annotString {[' ']...
              ['Res = ' sprintf('%3.3f',param(7))]}];
          elseif length(param) == 8
              annotString=[annotString {['kL / L = ' sprintf('%3.3f',param(7))]...
              [' ']...
              ['Res = ' sprintf('%3.3f',param(8))]}];
          end
end

startp      = fitinfo.start_point;
endp        = fitinfo.end_point;
formulaFunc = str2func(fitinfo.formula);


% Plot raw data and theoretic data in top plot
clf
set(gcf,'Position',[100 100 1000 800],'Name',['FIT: ' fitinfo.fittype],'NumberTitle','off');
ha=tight_subplot(2,1,0.1,0.1,[0.1 0.25]);
axes(ha(1));
plot(ha(1),tdata,ydata,'b+','MarkerSize',10,'Linewidth',2)
set(gca,'FontSize',16);
grid on
ylabel('Progress curve','FontSize',24);
xlabel('Time','FontSize',24);
annotation('textbox',[0.8 0.4 0.15 0.2],'FitBoxToText','on',...
    'BackgroundColor','white','FontSize',16,...
    'String',annotString);
hold on
plot(ha(1),tdata(startp:endp),real(formulaFunc(param,tdata(startp:endp))),...
    '-r','Linewidth',3)
hold off

% Plot residuals in bottom plot
axes(ha(2));
plot(ha(2),tdata(startp:endp),...
    ydata(startp:endp)-real(formulaFunc(param,tdata(startp:endp))) ...
    ,'m+','MarkerSize',10,'Linewidth',2)
set(gca,'FontSize',16);
grid on
ylabel('Residuals','FontSize',24);
xlabel('Time (Selection)','FontSize',24);

end